@@ -1,5 +1,6 @@
 from .ShareNotebook import ShareNotebook
 from .SplitNotebook import SplitNotebook
 from .Color import Color
-from .BeginLesson import begin
-from .GenerateCurriculum import GenerateCurriculum
\ No newline at end of file
+from .begin import begin
+from .GenerateCurriculum import GenerateCurriculum
+from .readme import generate_readme
\ No newline at end of file
